@@ -1,5 +1,5 @@
 // Symphonia
-// Copyright (c) 2019 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -21,7 +21,7 @@ use symphonia_core::codecs::{
 };
 use symphonia_core::codecs::CodecType;
 use symphonia_core::errors::{Result, decode_error, unsupported_error};
-use symphonia_core::io::ByteStream;
+use symphonia_core::io::ReadBytes;
 use symphonia_core::meta::Tag;
 use symphonia_metadata::riff;
 
@@ -59,7 +59,7 @@ impl<T: ParseChunkTag> ChunksReader<T> {
         }
     }
 
-    pub fn next<B: ByteStream>(&mut self, reader: &mut B) -> Result<Option<T>> {
+    pub fn next<B: ReadBytes>(&mut self, reader: &mut B) -> Result<Option<T>> {
         // Loop until a chunk is recognized and returned, or the end of stream is reached.
         loop {
             // Align to the next 2-byte boundary if not currently aligned.
@@ -86,7 +86,7 @@ impl<T: ParseChunkTag> ChunksReader<T> {
                 // When ffmpeg encodes wave to stdout the riff (parent) and data chunk lengths are
                 // (2^32)-1 since the size can't be known ahead of time.
                 if !(self.len == len && len == u32::MAX) {
-                    return decode_error("chunk length exceeds parent (list) chunk length");
+                    return decode_error("wav: chunk length exceeds parent (list) chunk length");
                 }
             }
 
@@ -109,7 +109,7 @@ impl<T: ParseChunkTag> ChunksReader<T> {
         }
     }
 
-    pub fn finish<B: ByteStream>(&mut self, reader: &mut B) -> Result<()>{
+    pub fn finish<B: ReadBytes>(&mut self, reader: &mut B) -> Result<()>{
         // If data is remaining in this chunk, skip it.
         if self.consumed < self.len {
             let remaining = self.len - self.consumed;
@@ -128,7 +128,7 @@ impl<T: ParseChunkTag> ChunksReader<T> {
 
 /// Common trait implemented for all chunks that are parsed by a `ChunkParser`.
 pub trait ParseChunk : Sized {
-    fn parse<B: ByteStream>(reader: &mut B, tag: [u8; 4], len: u32) -> Result<Self>;
+    fn parse<B: ReadBytes>(reader: &mut B, tag: [u8; 4], len: u32) -> Result<Self>;
 }
 
 /// `ChunkParser` is a utility struct for unifying the parsing of chunks.
@@ -147,7 +147,7 @@ impl<P: ParseChunk> ChunkParser<P> {
         }
     }
 
-    pub fn parse<B: ByteStream>(&self, reader: &mut B) -> Result<P> {
+    pub fn parse<B: ReadBytes>(&self, reader: &mut B) -> Result<P> {
         P::parse(reader, self.tag, self.len)
     }
 }
@@ -268,7 +268,7 @@ pub struct WaveFormatChunk {
 
 impl WaveFormatChunk {
 
-    fn read_pcm_fmt<B: ByteStream>(
+    fn read_pcm_fmt<B: ReadBytes>(
         reader: &mut B,
         bits_per_sample: u16,
         n_channels: u16,
@@ -284,7 +284,7 @@ impl WaveFormatChunk {
             18 => true,
             // WaveFormatEx with extra data length field and extra data.
             40 => true,
-            _ => return decode_error("malformed fmt_pcm chunk"),
+            _ => return decode_error("wav: malformed fmt_pcm chunk"),
         };
 
         // If there is extra data, read the length, and discard the extra data.
@@ -308,7 +308,7 @@ impl WaveFormatChunk {
             16 => CODEC_TYPE_PCM_S16LE,
             24 => CODEC_TYPE_PCM_S24LE,
             32 => CODEC_TYPE_PCM_S32LE,
-            _  => return decode_error("bits per sample for fmt_pcm must be 8, 16, 24 or 32 bits"),
+            _  => return decode_error("wav: bits per sample for fmt_pcm must be 8, 16, 24 or 32 bits"),
         };
 
         // The PCM format only supports 1 or 2 channels, for mono and stereo channel layouts,
@@ -316,13 +316,13 @@ impl WaveFormatChunk {
         let channels = match n_channels {
             1 => Channels::FRONT_LEFT,
             2 => Channels::FRONT_LEFT | Channels::FRONT_RIGHT,
-            _ => return decode_error("channel layout is not stereo or mono for fmt_pcm"),
+            _ => return decode_error("wav: channel layout is not stereo or mono for fmt_pcm"),
         };
 
         Ok(WaveFormatData::Pcm(WaveFormatPcm { bits_per_sample, channels, codec }))
     }
 
-    fn read_ieee_fmt<B: ByteStream>(
+    fn read_ieee_fmt<B: ReadBytes>(
         reader: &mut B,
         bits_per_sample: u16,
         n_channels: u16,
@@ -334,11 +334,11 @@ impl WaveFormatChunk {
             let extra_size = reader.read_u16()?;
 
             if extra_size != 0 {
-                return decode_error("extra data not expected for fmt_ieee chunk");
+                return decode_error("wav: extra data not expected for fmt_ieee chunk");
             }
         }
         else if len > 16 {
-            return decode_error("malformed fmt_ieee chunk");
+            return decode_error("wav: malformed fmt_ieee chunk");
         }
 
         // Officially, only 32-bit floats are supported, but Symphonia can handle 64-bit floats.
@@ -348,7 +348,7 @@ impl WaveFormatChunk {
         let codec = match bits_per_sample {
             32 => CODEC_TYPE_PCM_F32LE,
             64 => CODEC_TYPE_PCM_F64LE,
-            _  => return decode_error("bits per sample for fmt_ieee must be 32 or 64 bits"),
+            _  => return decode_error("wav: bits per sample for fmt_ieee must be 32 or 64 bits"),
         };
 
         // The IEEE format only supports 1 or 2 channels, for mono and stereo channel layouts,
@@ -356,27 +356,27 @@ impl WaveFormatChunk {
         let channels = match n_channels {
             1 => Channels::FRONT_LEFT,
             2 => Channels::FRONT_LEFT | Channels::FRONT_RIGHT,
-            _ => return decode_error("channel layout is not stereo or mono for fmt_ieee"),
+            _ => return decode_error("wav: channel layout is not stereo or mono for fmt_ieee"),
         };
 
         Ok(WaveFormatData::IeeeFloat(WaveFormatIeeeFloat { channels, codec }))
     }
 
-    fn read_ext_fmt<B: ByteStream>(
+    fn read_ext_fmt<B: ReadBytes>(
         reader: &mut B,
         bits_per_coded_sample: u16,
         len: u32,
     ) -> Result<WaveFormatData> {
         // WaveFormat for the extensible format must be extended to 40 bytes in length.
         if len < 40 {
-            return decode_error("malformed fmt_ext chunk");
+            return decode_error("wav: malformed fmt_ext chunk");
         }
 
         let extra_size = reader.read_u16()?;
 
         // The size of the extra data for the Extensible format is exactly 22 bytes.
         if extra_size != 22 {
-            return decode_error("extra data size not 22 bytes for fmt_ext chunk");
+            return decode_error("wav: extra data size not 22 bytes for fmt_ext chunk");
         }
 
         let bits_per_sample = reader.read_u16()?;
@@ -384,14 +384,14 @@ impl WaveFormatChunk {
         // Bits per coded sample for extensible formats is the width per sample as stored in the
         // stream. This must be a multiple of 8.
         if (bits_per_coded_sample & 0x7) != 0 {
-            return decode_error("bits per coded sample for fmt_ext must be a multiple of 8 bits");
+            return decode_error("wav: bits per coded sample for fmt_ext must be a multiple of 8");
         }
 
         // Bits per sample indicates the number of valid bits in the encoded sample. The sample is
         // encoded in a bits per coded sample width value, therefore the valid number of bits must
         // be at most bits per coded sample long.
         if bits_per_sample > bits_per_coded_sample {
-            return decode_error("bits per sample must be <= bits per coded sample for fmt_ext");
+            return decode_error("wav: bits per sample must be <= bits per coded sample for fmt_ext");
         }
 
         let channel_mask = reader.read_u32()?;
@@ -451,7 +451,7 @@ impl WaveFormatChunk {
                 // IEEE floating formats do not support truncated sample widths.
                 if bits_per_sample != bits_per_coded_sample {
                     return decode_error(
-                        "bits per sample for fmt_ext IEEE sub-type must equal bits per coded sample"
+                        "wav: bits per sample for fmt_ext IEEE sub-type must equal bits per coded sample"
                     );
                 }
 
@@ -460,13 +460,13 @@ impl WaveFormatChunk {
                     32 => CODEC_TYPE_PCM_F32LE,
                     64 => CODEC_TYPE_PCM_F64LE,
                     _ => return decode_error(
-                            "bits per sample for fmt_ext IEEE sub-type must be 32 or 64 bits"
+                            "wav: bits per sample for fmt_ext IEEE sub-type must be 32 or 64 bits"
                         ),
                 }
             }
             KSDATAFORMAT_SUBTYPE_ALAW => CODEC_TYPE_PCM_ALAW,
             KSDATAFORMAT_SUBTYPE_MULAW => CODEC_TYPE_PCM_MULAW,
-            _ => return unsupported_error("unsupported fmt_ext sub-type"),
+            _ => return unsupported_error("wav: unsupported fmt_ext sub-type"),
         };
 
         let channels = map_wave_channels(channel_mask);
@@ -480,13 +480,13 @@ impl WaveFormatChunk {
         }))
     }
 
-    fn read_alaw_pcm_fmt<B: ByteStream>(
+    fn read_alaw_pcm_fmt<B: ReadBytes>(
         reader: &mut B,
         n_channels: u16,
         len: u32,
     ) -> Result<WaveFormatData> {
         if len != 18 {
-            return decode_error("malformed fmt_alaw chunk");
+            return decode_error("wav: malformed fmt_alaw chunk");
         }
 
         let extra_size = reader.read_u16()?;
@@ -498,19 +498,19 @@ impl WaveFormatChunk {
         let channels = match n_channels {
             1 => Channels::FRONT_LEFT,
             2 => Channels::FRONT_LEFT | Channels::FRONT_RIGHT,
-            _ => return decode_error("channel layout is not stereo or mono for fmt_alaw")
+            _ => return decode_error("wav: channel layout is not stereo or mono for fmt_alaw")
         };
 
         Ok(WaveFormatData::ALaw(WaveFormatALaw{ codec: CODEC_TYPE_PCM_ALAW, channels }))
     }
 
-    fn read_mulaw_pcm_fmt<B: ByteStream>(
+    fn read_mulaw_pcm_fmt<B: ReadBytes>(
         reader: &mut B,
         n_channels: u16,
         len: u32,
     ) -> Result<WaveFormatData> {
         if len != 18 {
-            return decode_error("malformed fmt_mulaw chunk");
+            return decode_error("wav: malformed fmt_mulaw chunk");
         }
 
         let extra_size = reader.read_u16()?;
@@ -522,7 +522,7 @@ impl WaveFormatChunk {
         let channels = match n_channels {
             1 => Channels::FRONT_LEFT,
             2 => Channels::FRONT_LEFT | Channels::FRONT_RIGHT,
-            _ => return decode_error("channel layout is not stereo or mono for fmt_mulaw")
+            _ => return decode_error("wav: channel layout is not stereo or mono for fmt_mulaw")
         };
 
         Ok(WaveFormatData::MuLaw(WaveFormatMuLaw{ codec: CODEC_TYPE_PCM_MULAW, channels }))
@@ -530,11 +530,11 @@ impl WaveFormatChunk {
 }
 
 impl ParseChunk for WaveFormatChunk {
-    fn parse<B: ByteStream>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<WaveFormatChunk> {
+    fn parse<B: ReadBytes>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<WaveFormatChunk> {
         // WaveFormat has a minimal length of 16 bytes. This may be extended with format specific
         // data later.
         if len < 16 {
-            return decode_error("malformed fmt chunk");
+            return decode_error("wav: malformed fmt chunk");
         }
 
         let format = reader.read_u16()?;
@@ -575,7 +575,7 @@ impl ParseChunk for WaveFormatChunk {
                 Self::read_mulaw_pcm_fmt(reader, n_channels, len)
             }
             // Unsupported format.
-            _ => return unsupported_error("unsupported wave format"),
+            _ => return unsupported_error("wav: unsupported wave format"),
         }?;
 
         Ok(WaveFormatChunk { n_channels, sample_rate, avg_bytes_per_sec, block_align, format_data })
@@ -632,11 +632,11 @@ pub struct FactChunk {
 }
 
 impl ParseChunk for FactChunk {
-    fn parse<B: ByteStream>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<Self> {
+    fn parse<B: ReadBytes>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<Self> {
         // A Fact chunk is exactly 4 bytes long, though there is some mystery as to whether there
         // can be more fields in the chunk.
         if len != 4 {
-            return decode_error("malformed fact chunk");
+            return decode_error("wav: malformed fact chunk");
         }
 
         Ok(FactChunk{ n_frames: reader.read_u32()? })
@@ -657,17 +657,17 @@ pub struct ListChunk {
 }
 
 impl ListChunk {
-    pub fn skip<B: ByteStream>(&self, reader: &mut B) -> Result<()> {
+    pub fn skip<B: ReadBytes>(&self, reader: &mut B) -> Result<()> {
         ChunksReader::<NullChunks>::new(self.len).finish(reader)
     }
 }
 
 impl ParseChunk for ListChunk {
-    fn parse<B: ByteStream>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<Self> {
+    fn parse<B: ReadBytes>(reader: &mut B, _tag: [u8; 4], len: u32) -> Result<Self> {
         // A List chunk must contain atleast the list/form identifier. However, an empty list
         // (len == 4) is permissible.
         if len < 4 {
-            return decode_error("malformed list chunk");
+            return decode_error("wav: malformed list chunk");
         }
 
         Ok(ListChunk{
@@ -691,7 +691,7 @@ pub struct InfoChunk {
 }
 
 impl ParseChunk for InfoChunk {
-    fn parse<B: ByteStream>(reader: &mut B, tag: [u8; 4], len: u32) -> Result<InfoChunk> {
+    fn parse<B: ReadBytes>(reader: &mut B, tag: [u8; 4], len: u32) -> Result<InfoChunk> {
         // TODO: Apply limit.
         let mut value_buf = vec![0u8; len as usize];
         reader.read_buf_exact(&mut value_buf)?;
@@ -707,7 +707,7 @@ pub struct DataChunk {
 }
 
 impl ParseChunk for DataChunk {
-    fn parse<B: ByteStream>(_: &mut B, _: [u8; 4], len: u32) -> Result<DataChunk> {
+    fn parse<B: ReadBytes>(_: &mut B, _: [u8; 4], len: u32) -> Result<DataChunk> {
         Ok(DataChunk { len })
     }
 }
